#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "arenaEngine.h"


/* ======================================= TILES STUFF ======================================= */

static TILE *createTile(const int id, const char *img_name, const TILE_CONFIG config, TILE *prev) {
	TILE *tile = NULL;
	char imgPath[64] = {0};
	char logMess[64] = {0};

	// Allocate a new tile in memory
	tile = calloc(1,sizeof(TILE));
	if (tile == NULL) {
		sprintf(logMess, "Adding tile ID %d failed!", id);
		addLogWarn(logMess);
		return tile;
	}

	// Configure the tile
	tile->type_id = id;
	sprintf(imgPath, "data/tile_%s.png", img_name);
	tile->texture = IMG_Load(imgPath);
	tile->canBeMined = (config & TILE_CONFIG_MINEABLE);
	tile->isGround = (config & TILE_CONFIG_GROUND);
	tile->nextTile = NULL;

	if (!tile->texture) {
		sprintf(logMess, "Adding texture for tile ID %d failed!", id);
		addLogWarn(logMess);
		return tile;
	}

	// Link to the previous tile in list
	if (prev)
		prev->nextTile = tile;

	// Return the pointer to new allocated tile
	return tile;
}

static void deleteAllTiles(TILE *tileList) {
	if (!tileList) return;

	if (tileList->nextTile)
		deleteAllTiles(tileList->nextTile);
	
	if (tileList->texture)
		SDL_FreeSurface(tileList->texture);

	free(tileList);
}


/* ======================================= PLAYERS STUFF ======================================= */

static PLAYER *createPlayer(const int id, const char *img_name, int sPosX, int sPosY, PLAYER *prev) {
	PLAYER *p = NULL;
	char imgPath[64] = {0};
	char logMess[64] = {0};

	// Allocate a new player in memory
	p = calloc(1,sizeof(PLAYER));
	if (p == NULL) {
		sprintf(logMess, "Adding player ID %d failed!", id);
		addLogWarn(logMess);
		return p;
	}

	// Configure the player
	p->Id = id;
	p->PositionX = sPosX;
	p->PositionY = sPosY;
	sprintf(imgPath, "data/sprite_%s_0.png", img_name);
	p->texture[DOWN] = IMG_Load(imgPath);
	sprintf(imgPath, "data/sprite_%s_1.png", img_name);
	p->texture[UP] = IMG_Load(imgPath);
	sprintf(imgPath, "data/sprite_%s_2.png", img_name);
	p->texture[LEFT] = IMG_Load(imgPath);
	sprintf(imgPath, "data/sprite_%s_3.png", img_name);
	p->texture[RIGHT] = IMG_Load(imgPath);

	if (!p->texture[DOWN] || !p->texture[UP] || !p->texture[LEFT] || !p->texture[RIGHT]) {
		sprintf(logMess, "Adding texture for player ID %d failed!", id);
		addLogWarn(logMess);
		return p;
	}

	// Link to the previous player in list
	if (prev)
		prev->suiv = p;

	// Return the pointer to new allocated tile
	return p;
}

static void deleteAllPlayers(PLAYER *pList) {
	if (!pList) return;

	if (pList->suiv)
		deleteAllPlayers(pList->suiv);
	
	if (pList->texture[RIGHT])
		SDL_FreeSurface(pList->texture[RIGHT]);
	if (pList->texture[LEFT])
		SDL_FreeSurface(pList->texture[LEFT]);
	if (pList->texture[UP])
		SDL_FreeSurface(pList->texture[UP]);
	if (pList->texture[DOWN])
		SDL_FreeSurface(pList->texture[DOWN]);

	free(pList);
}



/* ======================================= ARENA GLOBAL FUNCTIONS ======================================= */

static void setRaceToPlayer(PLAYER *p, int race_id) {
	p->Race = race_id;
	switch(race_id) {
		//Race ORC
		case 1:	p->HealthPoints = 100;
				p->AttacksPoints = 10;
				break;

		//Race Elfe
		case 2:	p->HealthPoints = 80;
				p->AttacksPoints = 9;
				break;

		//Race Humaine
		default:
		case 3:	p->HealthPoints = 90;
				p->AttacksPoints = 9;
	}
}

TILE *createTileList(void) {
	uint16_t id = 0;
	TILE *tile_0 = NULL;
	TILE *tile_1 = NULL;
	TILE *tile_2 = NULL;
	TILE *tile_3 = NULL;
	TILE *tile_4 = NULL;
	TILE *tile_5 = NULL;

	// GRASS tile
	tile_0 = createTile(id++, 
		"grass",
		(TILE_CONFIG_GROUND),
		NULL
	);

	// ROCK tile
	tile_1 = createTile(id++, 
		"rock",
		(TILE_CONFIG_GROUND),
		tile_0
	);

	// TREE tile
	tile_2 = createTile(id++, 
		"tree",
		(TILE_CONFIG_NONE),
		tile_1
	);

	// WATER tile
	tile_3 = createTile(id++, 
		"water",
		(TILE_CONFIG_NONE),
		tile_2
	);

	// GOLD tile
	tile_4 = createTile(id++, 
		"gold",
		(TILE_CONFIG_GROUND | TILE_CONFIG_MINEABLE),
		tile_3
	);

	// SPAWN tile
	tile_5 = createTile(id++, 
		"spawn",
		(TILE_CONFIG_GROUND),
		tile_4
	);

	return tile_0;
}

PLAYER *createPlayerList(void) {
	PLAYER *p0 = NULL;
	PLAYER *p1 = NULL;
	PLAYER *p2 = NULL;
	PLAYER *p3 = NULL;
	int race;

	// Create the player instance
	p0 = createPlayer(0, "player", 0, 0, NULL);
	printf("Enter the player name: ");
	scanf("%s",p0->Name);

	do
	{
		printf("1: Orc\n2: Elf\n3: Human\nRace? ");
		scanf("%d",&race);
	} while((race < 1) || (race > 3));
	setRaceToPlayer(p0, race);

	// Create the AI instance
	p1 = createPlayer(1, "ia", (A_WIDTH-1), (A_HEIGHT-1), p0);
	strcpy(p1->Name, "SKY-NUT");
	setRaceToPlayer(p1, (random_lim(3)+1));

	//TODO
	p2 = createPlayer(2, "ia", 0, (A_HEIGHT-1), p1);
	p3 = createPlayer(3, "ia", (A_WIDTH-1), 0, p2);

	return p0;
}

void clearRessourcesCache(TILE *t, PLAYER *p) {
	deleteAllPlayers(p);
	deleteAllTiles(t);
}

ARENA_H_TILE* createHTile(ARENA_H_TILE* prevHTile) {
	ARENA_H_TILE* tile_h = NULL;

	if (prevHTile == NULL) {
		tile_h = calloc(1,sizeof(ARENA_H_TILE));		//Using calloc because of resetting all memory allocated to 0
		tile_h->type_id = 0;
		//tile_h->type_id = random_lim(5);
		//tile_h->playerOnTile = NULL;
		tile_h->nextRow = NULL;
		tile_h->nextColumn = NULL;
	} else if (prevHTile != NULL) {
		tile_h = calloc(1,sizeof(ARENA_H_TILE));
		prevHTile->nextRow = tile_h;
		tile_h->type_id = 0;
		//tile_h->type_id = random_lim(5);
		//tile_h->playerOnTile = NULL;
		tile_h->nextRow = NULL;
		tile_h->nextColumn = NULL;
	}

	return tile_h;
}

ARENA_W_TILE* createWTile(ARENA_H_TILE* prevHTile, ARENA_W_TILE* prevWTile) {
	ARENA_W_TILE* tile_w = NULL;

	if (prevHTile != NULL && prevWTile == NULL) {
		tile_w = calloc(1,sizeof(ARENA_W_TILE));
		prevHTile->nextColumn = tile_w;
		tile_w->type_id = 0;
		//tile_w->type_id = random_lim(5);
		//tile_w->playerOnTile = NULL;
		tile_w->nextColumn = NULL;

		return tile_w;
	} else if (prevHTile == NULL && prevWTile != NULL) {
		tile_w = calloc(1,sizeof(ARENA_W_TILE));
		prevWTile->nextColumn = tile_w;
		tile_w->type_id = 0;
		//tile_w->type_id = random_lim(5);
		//tile_w->playerOnTile = NULL;
		tile_w->nextColumn = NULL;
	}

	return NULL;
}

int setTileTypeID(ARENA_H_TILE* arena, int x, int y, int new_id) {
	int i;
	//x=coord_x-1;
	//y=coord_y-1;

	if (x > A_WIDTH || y > A_HEIGHT || x < 0 || y < 0) return -1;

	if (y == 0) {
		ARENA_H_TILE* tile_h = NULL;

		tile_h = arena;
		if (x != 0) {
			for (i=0;i<x;i++) {
				tile_h = tile_h->nextRow;
			}
		}

		tile_h->type_id = new_id;

		if (tile_h->type_id == new_id) return 0;
	} else {
		ARENA_W_TILE* tile_w = NULL;
		ARENA_H_TILE* tile_h = NULL;

		tile_h = arena;
		if (x != 0) {
			for (i=0;i<x;i++) {
				tile_h = tile_h->nextRow;
			}
		}

		tile_w = tile_h->nextColumn;
		if (y != 0) {
			for (i=0;i<y;i++) {
				tile_w = tile_w->nextColumn;
			}
		}

		tile_w->type_id = new_id;
		if (tile_w->type_id == new_id) return 0;
	}

	return -1;
}

ARENA_H_TILE* genNewArena(int size_h, int size_w) {
	ARENA_H_TILE* arenaOrigin = NULL;
	ARENA_H_TILE* TmpCursor_h = NULL;
	ARENA_W_TILE* TmpCursor_w = NULL;
	int z,i,j,rand_x,rand_y;

	/*
	 * Generate new flatgrass arena
	 */
	for(i=0;i<=size_h;i++){
		if (i==0) {
			arenaOrigin = createHTile(NULL);
			TmpCursor_h = arenaOrigin;
		} else {
			TmpCursor_h = createHTile(TmpCursor_h);
		}

		for(j=0;j<=size_w;j++){
			if (j==0) {
				TmpCursor_w = createWTile(TmpCursor_h, NULL);
			} else {
				createWTile(NULL, TmpCursor_w);
			}

			if (j!=0) TmpCursor_w = TmpCursor_w->nextColumn;
		}
	}

	/*
	 * Generate some rock area
	 */
	for (z=1; z <= A_WIDTH * A_HEIGHT * ROCK_GEN_RATE/100; z++) {
		rand_x = random_lim(A_WIDTH)-1;
		rand_y = random_lim(A_HEIGHT)-1;

		for (i=-2;i<=1;i++) {
			for (j=-1;j<=3;j++) {
				if (random_lim(101) < 65) {
					if (((rand_x + i) >= 0 && (rand_x + i) < A_WIDTH) && ((rand_y + j) >= 0 && (rand_y + j) < A_HEIGHT)) {
						if(setTileTypeID(arenaOrigin, rand_x+i, rand_y+j, ROCK)!=0) addLogWarn("Failed to add rock on arena."); else z++;
					}
				}
			}
		}
	}

	/*
	 * Generate some tree area on grass
	 */
	for (z=1; z <= A_WIDTH * A_HEIGHT * TREE_GEN_RATE/100; z++) {
		rand_x = random_lim(A_WIDTH)-1;
		rand_y = random_lim(A_HEIGHT)-1;

		for (i=-2;i<=2;i++) {
			for (j=-2;j<=2;j++) {
				if (random_lim(101) < 65) {
					if (((rand_x + i >= 0 && rand_x + i < A_WIDTH) && (rand_y + j >= 0 && rand_y + j < A_HEIGHT)) && getTileTypeID(arenaOrigin, rand_x+i, rand_y+j) == GRASS) {
						if(setTileTypeID(arenaOrigin, rand_x+i, rand_y+j, TREE)!=0) addLogWarn("Failed to tree add on arena."); else z++;
					}
				}
			}
		}
	}

	/*
	 * Generate some gold area on rock
	 */
	for (z=1; z <= A_WIDTH * A_HEIGHT * GOLD_GEN_RATE/100; z++) {
		rand_x = random_lim(A_WIDTH)-1;
		rand_y = random_lim(A_HEIGHT)-1;

		if (((rand_x + i >= 0 && rand_x + i <= A_WIDTH) && (rand_y + j >= 0 && rand_y + j <= A_HEIGHT)) && getTileTypeID(arenaOrigin, rand_x+i, rand_y+j) == ROCK) {
			if(setTileTypeID(arenaOrigin, rand_x+i, rand_y+j, GOLD)!=0) addLogWarn("Failed to add gold on arena."); else z++;
		}
	}

	/*
	 * Generate some water area on grass
	 */
	for (z=1; z <= A_WIDTH * A_HEIGHT * WATER_GEN_RATE/100; z++) {
		rand_x = random_lim(A_WIDTH)-1;
		rand_y = random_lim(A_HEIGHT)-1;

		for (i=-2;i<=2;i++) {
			for (j=-3;j<=3;j++) {
				if (i >= -1 && j >= -1 && i <= 1 && j <= 1) {
					if (((rand_x + i) >= 0 && (rand_x + i) < A_WIDTH) && ((rand_y + j) >= 0 && (rand_y + j) < A_HEIGHT)) {
						if(setTileTypeID(arenaOrigin, rand_x+i, rand_y+j, WATER)!=0) {
							addLogWarn("Failed to add water on arena.");
						}else z++;
					}
				} /*else {
					if (random_lim(101) < 60) {
						if ((rand_x + i >= 0 && rand_x + i <= A_WIDTH) && (rand_y + i >= 0 && rand_y + i <= A_HEIGHT)) {
							if(setTileTypeID(arenaOrigin, rand_x+i, rand_y+j, WATER)!=0) addLogWarn("Tree failed to add on arena."); else z++;
						}
					}
				}*/
			}
		}
	}

	/*
	 * Generate spawn
	 */
	for (z=0; z <= 1; z++) {
		if(setTileTypeID(arenaOrigin, 0+z, 0, SPAWN)!=0) addLogWarn("Failed to add spawn area up left corner");
		if(setTileTypeID(arenaOrigin, 0, 0+z, SPAWN)!=0) addLogWarn("Failed to add spawn area up left corner");
		if(setTileTypeID(arenaOrigin, 0+z, 0+z, SPAWN)!=0) addLogWarn("Failed to add spawn area up left corner");
	}
	for (z=0; z <= 1; z++) {
		if(setTileTypeID(arenaOrigin, A_WIDTH-1-z, A_HEIGHT-1, SPAWN)!=0) addLogWarn("Failed to add spawn area botton right corner");
		if(setTileTypeID(arenaOrigin, A_WIDTH-1, A_HEIGHT-1-z, SPAWN)!=0) addLogWarn("Failed to add spawn area botton right corner");
		if(setTileTypeID(arenaOrigin, A_WIDTH-1-z, A_HEIGHT-1-z, SPAWN)!=0) addLogWarn("Failed to add spawn area botton right corner");
	}

	return arenaOrigin;
}



/*
 * Arena delete functions
 */
void deleteWTile(ARENA_W_TILE* WTile) {
	if (WTile->nextColumn != NULL) {
		deleteWTile(WTile->nextColumn);
	}

	free(WTile);
}

void deleteHTile(ARENA_H_TILE* HTile) {
	if (HTile->nextRow != NULL) {
		deleteHTile(HTile->nextRow);
	}

	deleteWTile(HTile->nextColumn);
	free(HTile);
}

void deleteArena(ARENA_H_TILE* arena) {
	deleteHTile(arena);
}



/*
 * Arena status functions
 */
int getTileTypeID(ARENA_H_TILE* arena, int coord_x, int coord_y) {
	int type_id = -1;
	int i;
	//coord_x=x-1;
	//coord_y=y-1;

	if (coord_x > A_WIDTH || coord_y > A_HEIGHT || coord_x < 0 || coord_y < 0) return -1;

	if (coord_y == 0) {
		ARENA_H_TILE* tile_h = NULL;

		tile_h = arena;
		if (coord_x != 0) {
			for (i=0;i<coord_x;i++) {
				tile_h = tile_h->nextRow;
			}
		}

		type_id = tile_h->type_id;
	} else {
		ARENA_W_TILE* tile_w = NULL;
		ARENA_H_TILE* tile_h = NULL;

		tile_h = arena;
		if (coord_x != 0) {
			for (i=0;i<coord_x;i++) {
				tile_h = tile_h->nextRow;
			}
		}

		tile_w = tile_h->nextColumn;
		if (coord_y != 0) {
			for (i=0;i<coord_y;i++) {
				tile_w = tile_w->nextColumn;
			}
		}

		type_id = tile_w->type_id;
	}

	return type_id;
}

int isGroundTile(TILE *t_list, int id) {
	TILE *tmp_tile = NULL;
	int i=0;

	tmp_tile = t_list;
	while (i<id) {
		tmp_tile = tmp_tile->nextTile;
		i++;
	}

	return tmp_tile->isGround;
}

SDL_Surface *getTileSurfaceFromID(TILE *t_list, int id) {
	TILE *tmp_tile = NULL;
	int i=0;

	tmp_tile = t_list;
	while (i<id) {
		tmp_tile = tmp_tile->nextTile;
		i++;
	}

	return tmp_tile->texture;
}

int isPlayerAdjacent(PLAYER* p1, PLAYER* p2) {
	int adjPlayer = -1;

	if ((p1->PositionX-1 || p1->PositionX+1) == p2->PositionX && (p1->PositionY-1 || p1->PositionY+1) == p2->PositionY) adjPlayer = 1;

	return adjPlayer;
}

int isMoveCorrect(ARENA_H_TILE* arena, TILE *t_list, PLAYER *p_list, int coord_x, int coord_y, int direction) {
	PLAYER *tmp_player = NULL;
	int _x,_y,allow=0;

	if (direction==UP) {
		_x = coord_x;
		_y = coord_y-1;
	} else if (direction==DOWN) {
		_x = coord_x;
		_y = coord_y+1;
	} else if (direction==LEFT) {
		_x = coord_x-1;
		_y = coord_y;
	} else if (direction==RIGHT) {
		_x = coord_x+1;
		_y = coord_y;
	} else {
		_x = coord_x;
		_y = coord_y;
	}

	if (_x >= 0 && _y >= 0 && _x < A_HEIGHT && _y < A_WIDTH) {
		if (isGroundTile(t_list,getTileTypeID(arena,_x,_y))) allow=1;
	}

	tmp_player = p_list;
	do {
		if (tmp_player->PositionX == _x && tmp_player->PositionY == _y) allow=0;
		tmp_player = tmp_player->suiv;
	} while (tmp_player != NULL);

	return allow;
}

int NumberPlayerAlive(PLAYER *Head)
{
	int numberAlive=0;

	if(Head == NULL){
		printf("La liste est vide\n");
		return -1;
	} else {
		do {
			if(Head->HealthPoints > 0) {
				numberAlive++;
			}
			Head=Head->suiv;
		} while(Head != NULL);
	}

	return numberAlive;
}

int getRelativeDirection(SDL_Rect pos1, SDL_Rect pos2) {
	int _x,_y;

	_x = pos2.x - pos1.x;
	_y = pos2.y - pos1.y;

	if (_x>0) {
		return LEFT;
	} else if (_x<0) {
		return RIGHT;
	} else if (_y>0) {
		return DOWN;
	} else if (_y<0) {
		return UP;
	} else {
		return DOWN;
	}
}

int canAttackPlayer(PLAYER *p1, PLAYER *p2) {
	int allow = 0,_x,_y;

	_x = p2->PositionX - p1->PositionX;
	_y = p2->PositionY - p1->PositionY;

	if (_x <= 1 && _x >= -1 && _y <= 1 && _y >= -1) allow = 1;

	return allow;
}

void AttackPlayer(PLAYER *player1, PLAYER *player2)
{
	printf("Fonction Attaque\n");


		if((player1 != NULL) && (player2 != NULL))
		{

			if((player1->HealthPoints > 0) && (player2->HealthPoints > 0))
			{

				printf("\n\n** Tour **\n");

				printf("Attaque Joueur %d sur joueur %d \n",player1->Id,player2->Id);

				player2->HealthPoints = player2->HealthPoints - player1->AttacksPoints;

				printf("Joueur %d : %s    PV = %d\n ",player1->Id,player1->Name,player1->HealthPoints);
				printf("Joueur %d : %s    PV = %d\n ",player2->Id,player2->Name,player2->HealthPoints);

				/*if((player1->HealthPoints > 0) && (player2->HealthPoints > 0))
				{
					printf("\nAttaque Joueur %d sur joueur %d\n ",player2->Id,player1->Id);
					player1->HealthPoints = player1->HealthPoints - player2->AttacksPoints;

					printf("Joueur %d : %s    PV = %d\n ",player1->Id,player1->Name,player1->HealthPoints);
					printf("Joueur %d : %s    PV = %d \n",player2->Id,player2->Name,player2->HealthPoints);
				}*/
			}

		}
}

void ActionPlayer(ARENA_H_TILE* arena,TILE *t_list,PLAYER *p_list,PLAYER *player,int action)
{
	/* action = 1 --> Déplacement d'1 carreau vers le haut
	 * action = 2 --> Déplacement d'1 carreau vers la droite
	 * action = 3 --> Déplacement d'1 carreau vers le bas
	 * action = 4 --> Déplacement d'1 carreau vers la gauche
	 *
	 * */
	SDL_Point current_pos;


	 if(player != NULL)
	 {
		// récupère la position du personnage. La position de l'instance sur l'arène est récupérer par une fonction
		current_pos.x = player->PositionX;
		current_pos.y = player->PositionY;



		printf("\n**** Player  %s ****\n",player->Name);

		 if(action == 1)
		 {
			 printf("On veut aller vers le haut\n");
			 printf("ID case[%i][%i] : %i \n",current_pos.x,current_pos.y-1,getTileTypeID(arena, current_pos.x, current_pos.y-1));



			 if(isMoveCorrect(arena,t_list,p_list,current_pos.x,current_pos.y,UP))
			 {
				player->PositionY = (current_pos.y)-1;
				printf("Déplacement de 1 vers le haut\n La nouvelle position est de X: %i et Y: %i \n",player->PositionX,player->PositionY);
			 }
			 else
			 {
				 printf("Impossible d'aller vers le haut\n");
			 }
		 }
		 else if(action == 2)
		 {
			 printf("On veut aller vers la droite\n");
			 printf("ID case[%i][%i] : %i \n",current_pos.x+1,current_pos.y,getTileTypeID(arena, current_pos.x+1, current_pos.y));

			 if(isMoveCorrect(arena,t_list,p_list,current_pos.x,current_pos.y,RIGHT))
			 {
				player->PositionX = (current_pos.x)+1;
				printf("Déplacement de 1 vers la droite\n La nouvelle position est de X: %i et Y: %i \n",player->PositionX,player->PositionY);
			 }
			 else
			 {
				 printf("Impossible d'aller vers la droite\n");
			 }
		 }
		 else if(action == 3)
		 {
			 printf("On veut aller vers le bas\n");
			 printf("ID case[%i][%i] : %i \n",current_pos.x,current_pos.y+1,getTileTypeID(arena, current_pos.x, current_pos.y+1));

			 if(isMoveCorrect(arena,t_list,p_list,current_pos.x,current_pos.y,DOWN))
			 {
				player->PositionY = (current_pos.y)+1;
				printf("Déplacement de 1 vers le bas\n La nouvelle position est de X: %i et Y: %i \n",player->PositionX,player->PositionY);
			 }
			 else
			 {
				 printf("Impossible d'aller vers le bas\n");
			 }
		 }
		 else if(action == 4)
		 {
			 printf("On veut aller vers la gauche\n");
			 printf("ID case[%i][%i] : %i \n",current_pos.x-1,current_pos.y,getTileTypeID(arena, current_pos.x-1, current_pos.y));

			 if(isMoveCorrect(arena,t_list,p_list,current_pos.x,current_pos.y,LEFT))
			 {
				player->PositionX = (current_pos.x)-1;
				printf("Déplacement de 1 vers la gauche\n La nouvelle position est de X: %i et Y: %i \n",player->PositionX,player->PositionY);
			 }
			 else
			 {
				 printf("Impossible d'aller vers la gauche\n");
			 }
		 }
		 else
		 {
			printf("Autre action\n");
			printf("ID case[%i][%i] : %i \n",current_pos.x,current_pos.y-1,getTileTypeID(arena, current_pos.x, current_pos.y-1));

			printf("ID case[%i][%i] : %i \n",current_pos.x+1,current_pos.y,getTileTypeID(arena, current_pos.x+1, current_pos.y));

			printf("ID case[%i][%i] : %i \n",current_pos.x,current_pos.y+1,getTileTypeID(arena, current_pos.x, current_pos.y+1));

			printf("ID case[%i][%i] : %i \n",current_pos.x-1,current_pos.y,getTileTypeID(arena, current_pos.x-1, current_pos.y));


		 }
	 }
	 else
	 {
		printf("Echec, le joueur est NULL\n");
	 }
}
